export type BlurhashInstanceType = {
    memory: WebAssembly.Memory;
    malloc: (bytes: number) => number;
    free: (ptr: number) => void;
    decodeToArray: (stringPtr: number, width: number, height: number, punch: number, nChannels: number, pixelsArrayPtr: number) => number;
    isValidBlurhash: (stringPtr: number) => number;
};
/**
 * Initialize a WASM instance.
 * @returns A Blurhash WASM instance.
 */
export declare function initWasm(): Promise<BlurhashInstanceType>;
/**
 * Decode a Blurhash string into a Pixel Array that you can use to generate a Blurhash image.
 * @param instance A Blurhash WASM instance.
 * @param blurhashString A valid Blurhash string.
 * @param width The width of the image you want to generate.
 * @param height The height of the image you want to generate.
 * @returns A `Uint8ClampedArray` pixel array.
 */
export declare function decode(instance: BlurhashInstanceType, blurhashString: string, width: number, height: number): Uint8ClampedArray;
/**
 * Check if your Blurhash string is valid.
 * @param blurhashString A Blurhash string.
 * @returns `true` if your string is valid, `false` elsewise.
 */
export declare function isValidBlurhash(instance: BlurhashInstanceType, blurhashString: string): boolean;
